package com.foreverwin.mesnac.common.mapper;

import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Map;

@Repository
public interface ReportDataMapper {

    List<Map<String, Object>> findInspectionTask(Map paramMap);

    List<Map<String, Object>> findInspectionTaskDetail(Map paramMap);

    List<Map<String, Object>> findResourceLoadRateInfo(Map paramMap);

    List<Map<String, Object>> findResourceTypeLoadRateInfo(Map paramMap);

    List<Map<String, Object>> findResourceRepairDataStatInfo(Map paramMap);

    List<Map<String, Object>> findProductStateInfo(Map paramMap);

/*    void insertReportDateTimeByStartToDate(@Param("site") String site ,@Param("startFromDate") String startFromDate,@Param("startToDate") String startToDate);

    void deleteAllReportDateTime();*/

    List<Map<String, Object>> findWorkShopPassRate(Map paramMap);

    List<Map<String, Object>> findCheckUserPassRate(Map paramMap);

    List<Map<String, Object>> findUserPassRate(Map paramMap);

    List<Map<String, Object>> findInspectionDetailPassRate(Map paramMap);

    List<Map<String, Object>> findSectionPassRate(Map paramMap);

    List<Map<String, Object>> selectItemMoveData(Map paramMap);

    void doItemMove(@Param("site") String site, @Param("list") List<String> list);
}
